        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,14,15,19,20,23,24,26,27,28,29,30,32,33,34,35,37,38,39,40,42,43,44,47';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 16 <br>1,5,6,7,8,11,17,21,25,31,36,41,45,46,48,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 8 <br>9,10,12,13,16,18,22,49';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,14,15,19,20,23,24,26,27,28,29,30,32,33,34,35,37,38,39,40,42,43,44,47';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 16 <br>1,5,6,7,8,11,17,21,25,31,36,41,45,46,48,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 8 <br>9,10,12,13,16,18,22,49';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,14,15,19,20,23,24,26,27,28,29,30,32,33,34,35,37,38,39,40,42,43,44,47';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 16 <br>1,5,6,7,8,11,17,21,25,31,36,41,45,46,48,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 8 <br>9,10,12,13,16,18,22,49';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,14,15,19,20,23,24,26,27,28,29,30,32,33,34,35,37,38,39,40,42,43,44,47';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 16 <br>1,5,6,7,8,11,17,21,25,31,36,41,45,46,48,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 8 <br>9,10,12,13,16,18,22,49';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,14,15,19,20,23,24,26,27,28,29,30,32,33,34,35,37,38,39,40,42,43,44,47';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 16 <br>1,5,6,7,8,11,17,21,25,31,36,41,45,46,48,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 8 <br>9,10,12,13,16,18,22,49';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,14,15,19,20,23,24,26,27,28,29,30,32,33,34,35,37,38,39,40,42,43,44,47';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 16 <br>1,5,6,7,8,11,17,21,25,31,36,41,45,46,48,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260714 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 8 <br>9,10,12,13,16,18,22,49';}
}
